[![GPLv3 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/licenses/)
(to create)

# Spark Metabase API

A Python wrapper for the Metabase API \
Developed by the [Spark Tech team](https://www.spark.do/) ⭐️

## Installation

In construction 🚧

## To-Do

- [ ] Remove search based on names.
- [ ] Make sure admins are not removed when collection access is being restricted.
- [ ] Add functions for users, groups and permissions for all of that.
- [ ] Verbose all functions (parametrize it in function argument of course).

## Acknowledgements

- [Metabase API documentation](https://www.metabase.com/docs/latest/api-documentation)
- Inspired from [metabase_api_python](https://github.com/vvaezian/metabase_api_python)
